# tf-mpc [![Build Status](https://travis-ci.org/thiagopbueno/tfmpc.svg?branch=master)](https://travis-ci.org/thiagopbueno/tfmpc) [![Documentation Status](https://readthedocs.org/projects/tfmpc/badge/?version=latest)](https://tfmpc.readthedocs.io/en/latest/?badge=latest) [![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://github.com/thiagopbueno/tfmpc/blob/master/LICENSE)


# Quickstart

**tfmpc** is a Python3.6+ package available in PyPI.

```text
$ pip3 install -U tfmpc
```


# Usage

```text
$ tfmpc --help

```


# Documentation

Please refer to [https://tfmpc.readthedocs.io/](https://tfmpc.readthedocs.io/) for the code documentation.


# License

Copyright (c) 2020- Thiago P. Bueno All Rights Reserved.

tfmpc is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

tfmpc is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with tfmpc. If not, see http://www.gnu.org/licenses/.
